]> git.cameronkatri.com Git - mandoc.git/blobdiff - mandoc.h
Fix formatting of empty .Bl -inset item heads.
[mandoc.git] / mandoc.h
index be2f9f1028e2188fe3dcdf439d223e7909b90153..1a0256eb3d88c145d19ebf2a4320bd7da879ad4b 100644 (file)
--- a/mandoc.h
+++ b/mandoc.h
@@ -1,4 +1,4 @@
-/*     $Id: mandoc.h,v 1.125 2014/07/01 22:37:15 schwarze Exp $ */
+/*     $Id: mandoc.h,v 1.132 2014/07/03 23:24:56 schwarze Exp $ */
 /*
  * Copyright (c) 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
  * Copyright (c) 2010-2014 Ingo Schwarze <schwarze@openbsd.org>
 /*
  * Copyright (c) 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
  * Copyright (c) 2010-2014 Ingo Schwarze <schwarze@openbsd.org>
@@ -71,24 +71,28 @@ enum        mandocerr {
        MANDOCERR_SEC_MSEC, /* unexpected section: title for ... only */
 
        /* related to macros and nesting */
        MANDOCERR_SEC_MSEC, /* unexpected section: title for ... only */
 
        /* related to macros and nesting */
-       MANDOCERR_MACROOBS, /* skipping obsolete macro */
-       MANDOCERR_IGNPAR, /* skipping paragraph macro */
-       MANDOCERR_MOVEPAR, /* moving paragraph macro out of list */
-       MANDOCERR_IGNNS, /* skipping no-space macro */
-       MANDOCERR_SCOPENEST, /* blocks badly nested */
-       MANDOCERR_CHILD, /* child violates parent syntax */
-       MANDOCERR_NESTEDDISP, /* nested displays are not portable */
-       MANDOCERR_SCOPEREP, /* already in literal mode */
-       MANDOCERR_LINESCOPE, /* line scope broken */
-
-       /* related to missing macro arguments */
-       MANDOCERR_MACROEMPTY, /* skipping empty macro */
+       MANDOCERR_MACRO_OBS, /* obsolete macro: macro */
+       MANDOCERR_PAR_SKIP, /* skipping paragraph macro: macro ... */
+       MANDOCERR_PAR_MOVE, /* moving paragraph macro out of list: macro */
+       MANDOCERR_NS_SKIP, /* skipping no-space macro */
+       MANDOCERR_BLOCK_NEST, /* blocks badly nested: macro ... */
+       MANDOCERR_BD_NEST, /* nested displays are not portable: macro ... */
+       MANDOCERR_BL_MOVE, /* moving content out of list: macro */
+       MANDOCERR_VT_CHILD, /* .Vt block has child macro: macro */
+       MANDOCERR_FI_SKIP, /* fill mode already enabled, skipping .fi */
+       MANDOCERR_NF_SKIP, /* fill mode already disabled, skipping .nf */
+       MANDOCERR_LINESCOPE, /* line scope broken: macro breaks macro */
+
+       /* related to missing arguments */
+       MANDOCERR_REQ_EMPTY, /* skipping empty request: request */
+       MANDOCERR_COND_EMPTY, /* conditional request controls empty scope */
+       MANDOCERR_MACRO_EMPTY, /* skipping empty macro: macro */
        MANDOCERR_ARGCWARN, /* argument count wrong */
        MANDOCERR_DISPTYPE, /* missing display type */
        MANDOCERR_LISTFIRST, /* list type must come first */
        MANDOCERR_NOWIDTHARG, /* tag lists require a width argument */
        MANDOCERR_ARGCWARN, /* argument count wrong */
        MANDOCERR_DISPTYPE, /* missing display type */
        MANDOCERR_LISTFIRST, /* list type must come first */
        MANDOCERR_NOWIDTHARG, /* tag lists require a width argument */
+       MANDOCERR_IT_NOHEAD, /* missing head in list item: type */
        MANDOCERR_FONTTYPE, /* missing font type */
        MANDOCERR_FONTTYPE, /* missing font type */
-       MANDOCERR_WNOSCOPE, /* skipping end of block that is not open */
 
        /* related to bad macro arguments */
        MANDOCERR_IGNARGV, /* skipping argument */
 
        /* related to bad macro arguments */
        MANDOCERR_IGNARGV, /* skipping argument */
@@ -136,13 +140,13 @@ enum      mandocerr {
        MANDOCERR_MACRO, /* skipping unknown macro */
        MANDOCERR_REQUEST, /* NOT IMPLEMENTED: skipping request */
        MANDOCERR_ARGCOUNT, /* argument count wrong */
        MANDOCERR_MACRO, /* skipping unknown macro */
        MANDOCERR_REQUEST, /* NOT IMPLEMENTED: skipping request */
        MANDOCERR_ARGCOUNT, /* argument count wrong */
+       MANDOCERR_RS_SKIP, /* skipping invalid content in .Rs block: macro */
        MANDOCERR_STRAYTA, /* skipping column outside column list */
        MANDOCERR_NOSCOPE, /* skipping end of block that is not open */
        MANDOCERR_SCOPEBROKEN, /* missing end of block */
        MANDOCERR_SCOPEEXIT, /* scope open on exit */
        MANDOCERR_UNAME, /* uname(3) system call failed */
        /* FIXME: merge following with MANDOCERR_ARGCOUNT */
        MANDOCERR_STRAYTA, /* skipping column outside column list */
        MANDOCERR_NOSCOPE, /* skipping end of block that is not open */
        MANDOCERR_SCOPEBROKEN, /* missing end of block */
        MANDOCERR_SCOPEEXIT, /* scope open on exit */
        MANDOCERR_UNAME, /* uname(3) system call failed */
        /* FIXME: merge following with MANDOCERR_ARGCOUNT */
-       MANDOCERR_NOARGS, /* macro requires line argument(s) */
        MANDOCERR_NOBODY, /* macro requires body argument(s) */
        MANDOCERR_NOARGV, /* macro requires argument(s) */
        MANDOCERR_NUMERIC, /* request requires a numeric argument */
        MANDOCERR_NOBODY, /* macro requires body argument(s) */
        MANDOCERR_NOARGV, /* macro requires argument(s) */
        MANDOCERR_NUMERIC, /* request requires a numeric argument */